@@ -4,6 +4,7 @@ __all__ = ['__version__', 'Database', 'or_', 'and_', 'create_database']
 
 import os
 import json
+import numpy as np
 import pandas as pd
 from astropy.table import Table as AstropyTable
 from sqlalchemy.orm import sessionmaker
@@ -87,7 +88,8 @@ class AstrodbQuery(Query):
             DataFrame output of query
         """
 
-        df = pd.DataFrame(self.all())
+        # Relying on astropy to convert to pandas for simplicity as that handles the column names
+        df = self._make_astropy().to_pandas()
 
         # Apply spectra conversion
         if spectra is not None:
@@ -564,6 +566,7 @@ class Database:
 
         # Clear existing files first from that directory
         if clear_first:
+            print('Clearing existing JSON files...')
             for filename in os.listdir(directory):
                 os.remove(os.path.join(directory, filename))
 
@@ -585,6 +588,54 @@ class Database:
             self.save_json(row, directory)
 
     # Object input methods
+    def add_table_data(self, data, table, fmt='csv'):
+        """
+        Method to insert data into the database. Column names in the file must match those of the database table.
+        Additional columns in the supplied table are ignored.
+        Format options include:
+
+         - csv
+         - astropy
+         - pandas
+
+
+        Parameters
+        ----------
+        data : str or astropy.Table or pandas.DataFrame
+            Name of file or Table or DataFrame to load
+        table : str
+            Name of table to insert records into
+        fmt : str
+            Data format. Default: csv
+        """
+
+        if fmt.lower() == 'csv':
+            df = pd.read_csv(data)
+        elif fmt.lower() == 'astropy':
+            df = data.to_pandas()
+        elif fmt.lower() == 'pandas':
+            df = data.copy()
+        else:
+            raise RuntimeError(f'Unrecognized format {fmt}')
+
+        # Foreign key constraints will prevent inserts of missing sources,
+        # but for clarity we'll check first and exit if there are missing sources
+        if table != self._primary_table:
+            source_list = df[self._foreign_key].to_list()
+            primary_column = self.metadata.tables[self._primary_table].columns[self._primary_table_key]
+            matched_sources = self.query(primary_column).filter(primary_column.in_(source_list)).all()
+            missing_sources = np.setdiff1d(source_list, matched_sources)
+            if len(missing_sources) > 0:
+                print(f'{len(missing_sources)} missing source(s):')
+                print(missing_sources)
+                raise RuntimeError(f'There are missing entries in {self._primary_table} table. These must exist first.')
+
+        # Convert format for SQLAlchemy
+        data = [row.to_dict() for _, row in df.iterrows()]
+
+        # Load into specified table
+        self.metadata.tables[table].insert().execute(data)
+
     def load_table(self, table, directory):
         """
         Load a reference table to the database, expects there to be a file of the form [table].json
